@@ -1,6 +1,6 @@
-from ad import adstruc, adfunction
-from dual import DualNumber
-from functions import (
+from .ad import adstruc, adfunction
+from .dual import DualNumber
+from .functions import (
     cos,
     sin,
     tan,
